==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zu/admin/hardware/message.php <==
<?php

return array(

    'undeployable' 		=> '<strong>Thola: </strong> Lelifa limakwe njengamanje elingenakutholakali. Uma lesi simo sesishintshile, sicela ubuyekeze isimo sesifa.',
    'does_not_exist' 	=> 'Impahla ayikho.',
    'does_not_exist_or_not_requestable' => 'Zama okuhle. Lelifa alikho noma aliceli.',
    'assoc_users'	 	=> 'Leli fayela okwamanje lihlolwe kumsebenzisi futhi alikwazi ukususwa. Sicela uhlole ifa ekuqaleni, bese uzama ukususa futhi.',

    'create' => array(
        'error'   		=> 'Impahla ayidalwanga, sicela uzame futhi. :(',
        'success' 		=> 'Ifa lidalwe ngempumelelo. :)'
    ),

    'update' => array(
        'error'   			=> 'Ifa alizange libuyekezwe, sicela uzame futhi',
        'success' 			=> 'Ifa libuyekezwe ngempumelelo.',
        'nothing_updated'	=>  'Awekho amasimu akhethiwe, ngakho-ke akukho lutho olubuyekeziwe.',
    ),

    'restore' => array(
        'error'   		=> 'Ifa alizange libuyiselwe, sicela uzame futhi',
        'success' 		=> 'Ifa libuyiselwe ngempumelelo.'
    ),

    'audit' => array(
        'error'   		=> 'Ukuhlolwa kwamafa akuphumelelanga. Ngicela uzame futhi.',
        'success' 		=> 'I-akhawunti yokuthengisa ilandelwe ngempumelelo.'
    ),


    'deletefile' => array(
        'error'   => 'Ifayela alisusiwe. Ngicela uzame futhi.',
        'success' => 'Ifayili isusiwe ngempumelelo.',
    ),

    'upload' => array(
        'error'   => 'Amafayela (ama) awalayishiwe. Ngicela uzame futhi.',
        'success' => 'Amafayela (ama) alayishwe ngempumelelo.',
        'nofiles' => 'Awukakhethi noma yimaphi amafayela okulayishwa, noma ifayela ozama ukulilayisha likhulu kakhulu',
        'invalidfiles' => 'Ifayela elilodwa noma ngaphezulu likhulu kakhulu noma ifayelathi engavumelekile. Amafayela afakiwe avunyelwe i-png, i-gif, i-jpg, i-doc, i-docx, i-pdf, ne-txt.',
    ),

    'import' => array(
        'error'                 => 'Ezinye izinto azange zingenise ngendlela efanele.',
        'errorDetail'           => 'Izinto ezilandelayo azange zingeniswe ngenxa yamaphutha.',
        'success'               => "Ifayela lakho lifakiwe",
        'file_delete_success'   => "Ifayela lakho lisusiwe ngempumelelo",
        'file_delete_error'      => "Ifayela alikwazanga ukususwa",
    ),


    'delete' => array(
        'confirm'   	=> 'Uqinisekile ukuthi ufisa ukususa le mali?',
        'error'   		=> 'Kube nenkinga yokususa le mali. Ngicela uzame futhi.',
        'nothing_updated'   => 'Azikho izimpahla ezikhethiwe, ngakho akukho lutho olususwe.',
        'success' 		=> 'Impahla isusiwe ngempumelelo.'
    ),

    'checkout' => array(
        'error'   		=> 'Ifa alizange lihlolwe, sicela uzame futhi',
        'success' 		=> 'Ifa likhiphe ngempumelelo.',
        'user_does_not_exist' => 'Lo msebenzisi awuvumelekile. Ngicela uzame futhi.',
        'not_available' => 'Le mali ayitholakali ukuhlolwa!',
        'no_assets_selected' => 'You must select at least one asset from the list'
    ),

    'checkin' => array(
        'error'   		=> 'Ifa alizange lihlolwe, sicela uzame futhi',
        'success' 		=> 'Ifa lihlolwe ngempumelelo.',
        'user_does_not_exist' => 'Lo msebenzisi awuvumelekile. Ngicela uzame futhi.',
        'already_checked_in'  => 'Le mali isivele ihlolwe.',

    ),

    'requests' => array(
        'error'   		=> 'Ifa alizange liceliwe, sicela uzame futhi',
        'success' 		=> 'Ifa liceliwe ngempumelelo.',
        'canceled'      => 'Isicelo sokuhlola sikhanseliwe ngempumelelo'
    )

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zu/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		=> '<strong>Thola: </strong> Lelifa limakwe njengamanje elingenakutholakali. Uma lesi simo sesishintshile, sicela ubuyekeze isimo sesifa.',
    'does_not_exist' 	=> 'Impahla ayikho.',
    'does_not_exist_or_not_requestable' => 'That asset does not exist or is not requestable.',
    'assoc_users'	 	=> 'Leli fayela okwamanje lihlolwe kumsebenzisi futhi alikwazi ukususwa. Sicela uhlole ifa ekuqaleni, bese uzama ukususa futhi.',

    'create' => [
        'error'   		=> 'Impahla ayidalwanga, sicela uzame futhi. :(',
        'success' 		=> 'Ifa lidalwe ngempumelelo. :)',
    ],

    'update' => [
        'error'   			=> 'Ifa alizange libuyekezwe, sicela uzame futhi',
        'success' 			=> 'Ifa libuyekezwe ngempumelelo.',
        'nothing_updated'	=>  'Awekho amasimu akhethiwe, ngakho-ke akukho lutho olubuyekeziwe.',
    ],

    'restore' => [
        'error'   		=> 'Ifa alizange libuyiselwe, sicela uzame futhi',
        'success' 		=> 'Ifa libuyiselwe ngempumelelo.',
    ],

    'audit' => [
        'error'   		=> 'Ukuhlolwa kwamafa akuphumelelanga. Ngicela uzame futhi.',
        'success' 		=> 'I-akhawunti yokuthengisa ilandelwe ngempumelelo.',
    ],


    'deletefile' => [
        'error'   => 'Ifayela alisusiwe. Ngicela uzame futhi.',
        'success' => 'Ifayili isusiwe ngempumelelo.',
    ],

    'upload' => [
        'error'   => 'Amafayela (ama) awalayishiwe. Ngicela uzame futhi.',
        'success' => 'Amafayela (ama) alayishwe ngempumelelo.',
        'nofiles' => 'Awukakhethi noma yimaphi amafayela okulayishwa, noma ifayela ozama ukulilayisha likhulu kakhulu',
        'invalidfiles' => 'Ifayela elilodwa noma ngaphezulu likhulu kakhulu noma ifayelathi engavumelekile. Amafayela afakiwe avunyelwe i-png, i-gif, i-jpg, i-doc, i-docx, i-pdf, ne-txt.',
    ],

    'import' => [
        'error'                 => 'Ezinye izinto azange zingenise ngendlela efanele.',
        'errorDetail'           => 'Izinto ezilandelayo azange zingeniswe ngenxa yamaphutha.',
        'success'               => 'Ifayela lakho lifakiwe',
        'file_delete_success'   => 'Ifayela lakho lisusiwe ngempumelelo',
        'file_delete_error'      => 'Ifayela alikwazanga ukususwa',
    ],


    'delete' => [
        'confirm'   	=> 'Uqinisekile ukuthi ufisa ukususa le mali?',
        'error'   		=> 'Kube nenkinga yokususa le mali. Ngicela uzame futhi.',
        'nothing_updated'   => 'Azikho izimpahla ezikhethiwe, ngakho akukho lutho olususwe.',
        'success' 		=> 'Impahla isusiwe ngempumelelo.',
    ],

    'checkout' => [
        'error'   		=> 'Ifa alizange lihlolwe, sicela uzame futhi',
        'success' 		=> 'Ifa likhiphe ngempumelelo.',
        'user_does_not_exist' => 'Lo msebenzisi awuvumelekile. Ngicela uzame futhi.',
        'not_available' => 'Le mali ayitholakali ukuhlolwa!',
        'no_assets_selected' => 'You must select at least one asset from the list',
    ],

    'checkin' => [
        'error'   		=> 'Ifa alizange lihlolwe, sicela uzame futhi',
        'success' 		=> 'Ifa lihlolwe ngempumelelo.',
        'user_does_not_exist' => 'Lo msebenzisi awuvumelekile. Ngicela uzame futhi.',
        'already_checked_in'  => 'Le mali isivele ihlolwe.',

    ],

    'requests' => [
        'error'   		=> 'Ifa alizange liceliwe, sicela uzame futhi',
        'success' 		=> 'Ifa liceliwe ngempumelelo.',
        'canceled'      => 'Isicelo sokuhlola sikhanseliwe ngempumelelo',
    ],

];
